
# Type: classes


class definitions

URI: [meta:classes](https://w3id.org/biolink/biolinkml/meta/classes)


## Domain and Range

[SchemaDefinition](SchemaDefinition.md) ->  <sub>0..*</sub> [ClassDefinition](ClassDefinition.md)

## Parents


## Children


## Used by

 * [SchemaDefinition](SchemaDefinition.md)
